@@ -35,9 +35,16 @@ enum {
 	XL_NS_PKG_REL
 };
 
+#define XLSX_MaxCol	16384
+#define XLSX_MaxRow	1048576
+
 GnmConventions	*xlsx_conventions_new  (void);
 void		 xlsx_conventions_free (GnmConventions *conv);
 Workbook	*xlsx_conventions_add_extern_ref (GnmConventions *conv,
 						  char const *path);
+GnmConventions *xlsx_conventions_new  (void);
+void		xlsx_conventions_free (GnmConventions *conv);
+
+GOFormat       *xlsx_pivot_date_fmt   (void);
 
 #endif /* GNM_XLSX_UTILS_H */
