@@ -112,11 +112,10 @@ gboolean cmd_define_name	(WorkbookControl *wbc, char const *name,
 				 char const *descriptor);
 gboolean cmd_remove_name        (WorkbookControl *wbc, GnmNamedExpr *nexpr);
 
-/* FIXME: figure out how to resolve these better.  */
-struct _scenario_t;
+/* FIXME: figure out how to resolve this better.  */
 struct _scenario_cmd_t;
-gboolean cmd_scenario_add (WorkbookControl *wbc, struct _scenario_t *s, Sheet *sheet);
-gboolean cmd_scenario_mngr (WorkbookControl *wbc, struct _scenario_cmd_t *sc, Sheet *sheet);
+gboolean cmd_scenario_add (WorkbookControl *wbc, GnmScenario *s, Sheet *sheet);
+gboolean cmd_scenario_mngr (WorkbookControl *wbc, GnmScenario *sc);
 
 /* FIXME: figure out how to resolve this better.  */
 struct _data_shuffling_t;
@@ -128,8 +127,8 @@ gboolean cmd_text_to_columns (WorkbookControl *wbc,
 			      GnmRange const *target, Sheet *target_sheet,
 			      GnmCellRegion *content);
 
-gboolean cmd_solver (WorkbookControl *wbc,
-		     GSList *cells, GSList *ov, GSList *nv);
+gboolean cmd_solver (WorkbookControl *wbc, const char *text,
+		     GOUndo *undo, GOUndo *redo);
 
 gboolean cmd_goal_seek (WorkbookControl *wbc,
 			GnmCell *cell, GnmValue *ov, GnmValue *nv);
