@@ -20,12 +20,11 @@
 /* ../sheet-object-widget.c    */
 #define GNUMERIC_HELP_LINK_SO_FRAME	 "sect-graphics-drawings"
 #define GNUMERIC_HELP_LINK_SO_ADJUSTMENT "sect-graphics-drawings"
+#define GNUMERIC_HELP_LINK_SO_BUTTON	 "sect-graphics-drawings"
+#define GNUMERIC_HELP_LINK_SO_RADIO_BUTTON "sect-graphics-drawings"
 #define GNUMERIC_HELP_LINK_SO_CHECKBOX	 "sect-graphics-drawings"
 #define GNUMERIC_HELP_LINK_SO_LIST	 "sect-graphics-drawings"
 
-/* dialog-autocorrect.c        */
-#define GNUMERIC_HELP_LINK_AUTOCORRECT "sect-data-entry"
-
 /* dialog-autofilter.c         */
 #define GNUMERIC_HELP_LINK_AUTOFILTER_TOP_TEN "sect-data-modify"
 #define GNUMERIC_HELP_LINK_AUTOFILTER_CUSTOM "sect-data-modify"
@@ -91,6 +90,7 @@
 
 /* dialog-preferences.c       */
 #define GNUMERIC_HELP_LINK_PREFERENCES "sect-configuration-preferences"
+#define GNUMERIC_HELP_LINK_AUTOCORRECT "sect-data-entry"
 
 /* dialog-printer-setup.c     */
 #define GNUMERIC_HELP_LINK_PRINTER_SETUP_HEADER_CUSTOMIZATION "sect-printing-setup"
@@ -155,6 +155,9 @@
 /* dialog-analysis-tool-kaplan-meier.c */
 #define GNUMERIC_HELP_LINK_KAPLAN_MEIER "sect-analysis-statistical"
 
+/* dialog-analysis-tool-normality.c */
+#define GNUMERIC_HELP_LINK_NORMALITY "sect-analysis-statistical"
+
 /* dialog-consolidate.c     */
 #define GNUMERIC_HELP_LINK_CONSOLIDATE ""
 
@@ -164,6 +167,9 @@
 /* dialog-random-generator.c */
 #define GNUMERIC_HELP_LINK_RANDOM_GENERATOR "sect-dataentryadv"
 
+/* dialog-random-generator-cor.c */
+#define GNUMERIC_HELP_LINK_RANDOM_GENERATOR_COR "sect-dataentryadv"
+
 /* dialog-scenarios.c */
 #define GNUMERIC_HELP_LINK_SCENARIOS_ADD "sect-advanced-analysis-scenarios"
 #define GNUMERIC_HELP_LINK_SCENARIOS_VIEW "sect-advanced-analysis-scenarios"
