@@ -34,6 +34,11 @@ gnm_float logfbit (gnm_float x);
 gnm_float logspace_add (gnm_float logx, gnm_float logy);
 gnm_float logspace_sub (gnm_float logx, gnm_float logy);
 
+gnm_float gnm_cot (gnm_float x);
+gnm_float gnm_acot (gnm_float x);
+gnm_float gnm_coth (gnm_float x);
+gnm_float gnm_acoth (gnm_float x);
+
 gnm_float beta (gnm_float a, gnm_float b);
 gnm_float lbeta3 (gnm_float a, gnm_float b, int *sign);
 
@@ -150,6 +155,8 @@ gnm_float random_levy_skew      (gnm_float c, gnm_float alpha,
 gnm_float random_exppow         (gnm_float a, gnm_float b);
 gnm_float random_landau         (void);
 gnm_float random_gaussian_tail  (gnm_float a, gnm_float sigma);
+gnm_float random_skew_normal    (gnm_float a);
+gnm_float random_skew_tdist     (gnm_float nu, gnm_float a);
 
 /* The probability density functions. */
 gnm_float random_exppow_pdf     (gnm_float x, gnm_float a, gnm_float b);
