@@ -1,14 +1,16 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-#ifndef GNM_SHEET_FILTER_COMBO_H
-#define GNM_SHEET_FILTER_COMBO_H
+#ifndef _GNM_SHEET_FILTER_COMBO_H_
+# define _GNM_SHEET_FILTER_COMBO_H_
 
 #include "sheet-object-impl.h"
 
+G_BEGIN_DECLS
+
 typedef struct {
 	SheetObject parent;
 
 	GnmFilterCondition *cond;
-	GnmFilter   	   *filter;
+	GnmFilter	   *filter;
 } GnmFilterCombo;
 
 #define GNM_FILTER_COMBO_TYPE     (gnm_filter_combo_get_type ())
@@ -18,4 +20,8 @@ typedef struct {
 GType gnm_filter_combo_get_type (void);
 void  gnm_filter_combo_apply    (GnmFilterCombo *fcombo, Sheet *target_sheet);
 
-#endif /* GNM_SHEET_FILTER_COMBO_H */
+int   gnm_filter_combo_index    (GnmFilterCombo *fcombo);
+
+G_END_DECLS
+
+#endif /* _GNM_SHEET_FILTER_COMBO_H_ */
