@@ -41,19 +41,17 @@
 #include "mstyle.h"
 #include "validation.h"
 #include "validation-combo.h"
+#include "gnm-sheet-slicer.h"
+#include "gnm-sheet-slicer-combo.h"
 #include "position.h"
 #include "cell.h"
 #include "gutils.h"
 #include "command-context.h"
 #include "auto-format.h"
 #include "sheet-object.h"
+#include "gnumeric-gconf.h"
 
-#include <goffice/app/file.h>
-#include <goffice/app/go-doc.h>
-#include <goffice/app/io-context.h>
-#include <goffice/utils/go-file.h>
-#include <goffice/utils/go-glib-extras.h>
-#include <goffice/utils/go-locale.h>
+#include <goffice/goffice.h>
 #include <gsf/gsf.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-stdio.h>
@@ -78,7 +76,14 @@ enum {
 	PROP_AUTO_EXPR_FUNC,
 	PROP_AUTO_EXPR_DESCR,
 	PROP_AUTO_EXPR_MAX_PRECISION,
-	PROP_AUTO_EXPR_TEXT
+	PROP_AUTO_EXPR_TEXT,
+	PROP_SHOW_HORIZONTAL_SCROLLBAR,
+	PROP_SHOW_VERTICAL_SCROLLBAR,
+	PROP_SHOW_NOTEBOOK_TABS,
+	PROP_DO_AUTO_COMPLETION,
+	PROP_PROTECTED,
+	PROP_PREFERRED_WIDTH,
+	PROP_PREFERRED_HEIGHT
 };
 
 /* WorkbookView signals */
@@ -198,26 +203,37 @@ wb_view_is_protected (WorkbookView *wbv, gboolean check_sheet)
 }
 
 void
-wb_view_set_attribute (WorkbookView *wbv, char const *name,
-		       char const *value)
+wb_view_set_attribute (WorkbookView *wbv, char const *name, char const *value)
 {
 	gboolean res;
+	GObject *obj;
+	const char *tname;
 
 	g_return_if_fail (IS_WORKBOOK_VIEW (wbv));
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (value != NULL);
 
+	obj = G_OBJECT (wbv);
 	res = !g_ascii_strcasecmp (value, "TRUE");
-	if (!strcmp (name , "WorkbookView::show_horizontal_scrollbar"))
-		wbv->show_horizontal_scrollbar = res;
-	else if (!strcmp (name , "WorkbookView::show_vertical_scrollbar"))
-		wbv->show_vertical_scrollbar = res;
-	else if (!strcmp (name , "WorkbookView::show_notebook_tabs"))
-		wbv->show_notebook_tabs = res;
-	else if (!strcmp (name , "WorkbookView::do_auto_completion"))
-		wbv->do_auto_completion = res;
-	else if (!strcmp (name , "WorkbookView::is_protected"))
-		wbv->is_protected = res;
+
+	if (strncmp (name, "WorkbookView::", 14) == 0)
+		tname = name + 14;
+	else if (strncmp (name, "Workbook::", 10) == 0)
+		/* Some old files have this.  */
+		tname = name + 10;
+	else
+		tname = "nope";
+
+	if (!strcmp (tname , "show_horizontal_scrollbar"))
+		g_object_set (obj, "show_horizontal_scrollbar", res, NULL);
+	else if (!strcmp (tname , "show_vertical_scrollbar"))
+		g_object_set (obj, "show_vertical_scrollbar", res, NULL);
+	else if (!strcmp (tname , "show_notebook_tabs"))
+		g_object_set (obj, "show_notebook_tabs", res, NULL);
+	else if (!strcmp (tname , "do_auto_completion"))
+		g_object_set (obj, "do_auto_completion", res, NULL);
+	else if (!strcmp (tname , "is_protected"))
+		g_object_set (obj, "protected", res, NULL);
 	else
 		g_warning ("WorkbookView unknown arg '%s'", name);
 }
@@ -227,9 +243,10 @@ wb_view_preferred_size (WorkbookView *wbv, int w, int h)
 {
 	g_return_if_fail (IS_WORKBOOK_VIEW (wbv));
 
-	/* FIXME : should we notify the controls ? */
-	wbv->preferred_width = w;
-	wbv->preferred_height = h;
+	g_object_set (G_OBJECT (wbv),
+		      "preferred-width", w,
+		      "preferred-height", h,
+		      NULL);
 }
 
 void
@@ -237,6 +254,8 @@ wb_view_style_feedback (WorkbookView *wbv)
 {
 	SheetView *sv;
 	GnmStyle const *style;
+	GnmSheetSlicer const *dslicer;
+	GODataSlicerField *dsfield;
 	GnmValidation const *val;
 	GOFormat const *fmt_style, *fmt_cell;
 	GnmCell *cell;
@@ -272,29 +291,35 @@ wb_view_style_feedback (WorkbookView *wbv)
 		gnm_style_unref (wbv->current_style);
 	wbv->current_style = style;
 
-	if (wbv->validation_combo != NULL) {
-		sheet_object_clear_sheet (wbv->validation_combo);
-		g_object_unref (wbv->validation_combo);
-		wbv->validation_combo = NULL;
+	if (wbv->in_cell_combo != NULL) {
+		sheet_object_clear_sheet (wbv->in_cell_combo);
+		g_object_unref (wbv->in_cell_combo);
+		wbv->in_cell_combo = NULL;
 	}
 
 	if (gnm_style_is_element_set (style, MSTYLE_VALIDATION) &&
 	    NULL != (val = gnm_style_get_validation (style)) &&
 	    val->type == VALIDATION_TYPE_IN_LIST &&
-	    val->use_dropdown) {
+	    val->use_dropdown)
+		wbv->in_cell_combo = gnm_validation_combo_new (val, sv);
+	else if (NULL != (dslicer = gnm_sheet_slicers_at_pos (sv->sheet, &sv->edit_pos)) &&
+		   NULL != (dsfield = gnm_sheet_slicer_field_header_at_pos (dslicer, &sv->edit_pos)))
+		wbv->in_cell_combo = g_object_new (gnm_sheet_slicer_combo_get_type (),
+						   "sheet-view", sv,
+						   "field",	 dsfield,
+						   NULL);
+
+	if (NULL != wbv->in_cell_combo)
+	{
 		float const a_offsets [4] = { 0., 0., 1., 1. };
 		SheetObjectAnchor  anchor;
 		GnmRange corner;
 		GnmRange const *r;
-
-		r = gnm_sheet_merge_contains_pos (sv->sheet, &sv->edit_pos);
-		if (r == NULL)
+		if (NULL == (r = gnm_sheet_merge_contains_pos (sv->sheet, &sv->edit_pos)))
 			r = range_init_cellpos (&corner, &sv->edit_pos);
-		wbv->validation_combo = gnm_validation_combo_new (val, sv);
-		sheet_object_anchor_init (&anchor, r, a_offsets,
-			GOD_ANCHOR_DIR_DOWN_RIGHT);
-		sheet_object_set_anchor (wbv->validation_combo, &anchor);
-		sheet_object_set_sheet (wbv->validation_combo, sv_sheet (sv));
+		sheet_object_anchor_init (&anchor, r, a_offsets, GOD_ANCHOR_DIR_DOWN_RIGHT);
+		sheet_object_set_anchor (wbv->in_cell_combo, &anchor);
+		sheet_object_set_sheet (wbv->in_cell_combo, sv->sheet);
 	}
 
 	if (update_controls) {
@@ -465,12 +490,11 @@ accumulate_regions (SheetView *sv,  GnmRange const *r, gpointer closure)
 void
 wb_view_auto_expr_recalc (WorkbookView *wbv)
 {
-	GnmFuncEvalInfo ei;
 	GnmEvalPos      ep;
 	GnmExprList	*selection = NULL;
 	GnmValue	*v;
 	SheetView	*sv;
-	GnmExpr const   *expr;
+	GnmExprTop const *texpr;
 
 	g_return_if_fail (IS_WORKBOOK_VIEW (wbv));
 
@@ -482,11 +506,11 @@ wb_view_auto_expr_recalc (WorkbookView *wbv)
 
 	sv_selection_apply (sv, &accumulate_regions, FALSE, &selection);
 
-	expr = gnm_expr_new_funcall (wbv->auto_expr_func, selection);
+	texpr = gnm_expr_top_new
+		(gnm_expr_new_funcall (wbv->auto_expr_func, selection));
 
-	ei.pos = eval_pos_init_sheet (&ep, wbv->current_sheet);
-	ei.func_call = &expr->func;
-	v = function_call_with_exprs (&ei, 0);
+	eval_pos_init_sheet (&ep, wbv->current_sheet);
+	v = gnm_expr_top_eval (texpr, &ep, GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
 
 	if (v) {
 		GString *str = g_string_new (wbv->auto_expr_descr);
@@ -496,21 +520,15 @@ wb_view_auto_expr_recalc (WorkbookView *wbv)
 		g_string_append_c (str, '=');
 		if (!wbv->auto_expr_use_max_precision) {
 			format = VALUE_FMT (v);
-			if (!format) {
-				const GnmExprTop *fcall =
-					gnm_expr_top_new (expr);
-				expr = NULL;
+			if (!format)
 				format = tmp_format =
-					auto_style_format_suggest (fcall, ei.pos);
-				gnm_expr_top_unref (fcall);
-			}
+					auto_style_format_suggest (texpr, &ep);
 		}
 
 		if (format) {
 			format_value_gstring (str, format, v, NULL,
 					      -1, workbook_date_conv (wb_view_get_workbook (wbv)));
-			if (tmp_format)
-				go_format_unref (tmp_format);
+			go_format_unref (tmp_format);
 		} else {
 			g_string_append (str, value_peek_string (v));
 		}
@@ -523,8 +541,7 @@ wb_view_auto_expr_recalc (WorkbookView *wbv)
 		g_object_set (wbv, "auto-expr-text", "Internal ERROR", NULL);
 	}
 
-	if (expr)
-		gnm_expr_free (expr);
+	gnm_expr_top_unref (texpr);
 }
 
 /* perform whatever initialization of a control that is necessary when it
@@ -642,6 +659,27 @@ wb_view_set_property (GObject *object, guint property_id,
 	case PROP_AUTO_EXPR_TEXT:
 		wb_view_auto_expr_text (wbv, g_value_get_string (value));
 		break;
+	case PROP_SHOW_HORIZONTAL_SCROLLBAR:
+		wbv->show_horizontal_scrollbar = !!g_value_get_boolean (value);
+		break;
+	case PROP_SHOW_VERTICAL_SCROLLBAR:
+		wbv->show_vertical_scrollbar = !!g_value_get_boolean (value);
+		break;
+	case PROP_SHOW_NOTEBOOK_TABS:
+		wbv->show_notebook_tabs = !!g_value_get_boolean (value);
+		break;
+	case PROP_DO_AUTO_COMPLETION:
+		wbv->do_auto_completion = !!g_value_get_boolean (value);
+		break;
+	case PROP_PROTECTED:
+		wbv->is_protected = !!g_value_get_boolean (value);
+		break;
+	case PROP_PREFERRED_WIDTH:
+		wbv->preferred_width = g_value_get_int (value);
+		break;
+	case PROP_PREFERRED_HEIGHT:
+		wbv->preferred_height = g_value_get_int (value);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -667,6 +705,27 @@ wb_view_get_property (GObject *object, guint property_id,
 	case PROP_AUTO_EXPR_TEXT:
 		g_value_set_string (value, wbv->auto_expr_text);
 		break;
+	case PROP_SHOW_HORIZONTAL_SCROLLBAR:
+		g_value_set_boolean (value, wbv->show_horizontal_scrollbar);
+		break;
+	case PROP_SHOW_VERTICAL_SCROLLBAR:
+		g_value_set_boolean (value, wbv->show_vertical_scrollbar);
+		break;
+	case PROP_SHOW_NOTEBOOK_TABS:
+		g_value_set_boolean (value, wbv->show_notebook_tabs);
+		break;
+	case PROP_DO_AUTO_COMPLETION:
+		g_value_set_boolean (value, wbv->do_auto_completion);
+		break;
+	case PROP_PROTECTED:
+		g_value_set_boolean (value, wbv->is_protected);
+		break;
+	case PROP_PREFERRED_WIDTH:
+		g_value_set_int (value, wbv->preferred_width);
+		break;
+	case PROP_PREFERRED_HEIGHT:
+		g_value_set_int (value, wbv->preferred_height);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -726,10 +785,10 @@ wb_view_finalize (GObject *object)
 		gnm_style_unref (wbv->current_style);
 		wbv->current_style = NULL;
 	}
-	if (wbv->validation_combo != NULL) {
-		sheet_object_clear_sheet (wbv->validation_combo);
-		g_object_unref (wbv->validation_combo);
-		wbv->validation_combo = NULL;
+	if (wbv->in_cell_combo != NULL) {
+		sheet_object_clear_sheet (wbv->in_cell_combo);
+		g_object_unref (wbv->in_cell_combo);
+		wbv->in_cell_combo = NULL;
 	}
 
 	parent_class->finalize (object);
@@ -781,6 +840,69 @@ workbook_view_class_init (GObjectClass *gobject_class)
 				      NULL,
 				      GSF_PARAM_STATIC |
 				      G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_SHOW_HORIZONTAL_SCROLLBAR,
+		 g_param_spec_boolean ("show-horizontal-scrollbar",
+				       _("Show horizontal scrollbar"),
+				       _("Show the horizontal scrollbar"),
+				       TRUE,
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_SHOW_VERTICAL_SCROLLBAR,
+		 g_param_spec_boolean ("show-vertical-scrollbar",
+				       _("Show vertical scrollbar"),
+				       _("Show the vertical scrollbar"),
+				       TRUE,
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_SHOW_NOTEBOOK_TABS,
+		 g_param_spec_boolean ("show-notebook-tabs",
+				       _("Show notebook tabs"),
+				       _("Show the notebook tabs for sheets"),
+				       TRUE,
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_DO_AUTO_COMPLETION,
+		 g_param_spec_boolean ("do-auto-completion",
+				       _("Do auto completion"),
+				       _("Auto-complete text"),
+				       gnm_conf_get_core_gui_editing_autocomplete (),
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_PROTECTED,
+		 g_param_spec_boolean ("protected",
+				       _("Protected"),
+				       _("Is view protected?"),
+				       FALSE,
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_PREFERRED_WIDTH,
+		 g_param_spec_int ("preferred-width",
+				   _("Preferred width"),
+				   _("Preferred width"),
+				   1, G_MAXINT, 1024,
+				   GSF_PARAM_STATIC |
+				   G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_PREFERRED_HEIGHT,
+		 g_param_spec_int ("preferred-height",
+				   _("Preferred height"),
+				   _("Preferred height"),
+				   1, G_MAXINT, 768,
+				   GSF_PARAM_STATIC |
+				   G_PARAM_READWRITE));
 
 	parent_class = g_type_class_peek_parent (gobject_class);
 }
@@ -805,11 +927,11 @@ workbook_view_new (Workbook *wb)
 	wbv->show_horizontal_scrollbar = TRUE;
 	wbv->show_vertical_scrollbar = TRUE;
 	wbv->show_notebook_tabs = TRUE;
-	wbv->do_auto_completion = gnm_app_use_auto_complete ();
+	wbv->do_auto_completion = gnm_conf_get_core_gui_editing_autocomplete ();
 	wbv->is_protected = FALSE;
 
 	wbv->current_style      = NULL;
-	wbv->validation_combo   = NULL;
+	wbv->in_cell_combo      = NULL;
 
 	wbv->current_sheet      = NULL;
 	wbv->current_sheet_view = NULL;
@@ -836,13 +958,13 @@ workbook_view_new (Workbook *wb)
  * @wbv : #WorkbookView
  * @fs  : #GOFileSaver
  * @output : #GsfOutput
- * @io_context : #IOContext
+ * @io_context : #GOIOContext
  *
  * NOTE : Temporary api until we get the new output framework.
  **/
 void
 wbv_save_to_output (WorkbookView *wbv, GOFileSaver const *fs,
-		    GsfOutput *output, IOContext *io_context)
+		    GsfOutput *output, GOIOContext *io_context)
 {
 	GError const *err;
 	char const   *msg;
@@ -858,13 +980,13 @@ wbv_save_to_output (WorkbookView *wbv, GOFileSaver const *fs,
 	if (NULL == (msg = err->message))
 		msg = _("An unexplained error happened while saving.");
 	g_printerr ("  ==> %s\n", msg);
-	if (!gnumeric_io_error_occurred (io_context))
+	if (!go_io_error_occurred (io_context))
 		go_cmd_context_error_export (GO_CMD_CONTEXT (io_context), msg);
 }
 
 void
 wb_view_save_to_uri (WorkbookView *wbv, GOFileSaver const *fs,
-		     char const *uri, IOContext *io_context)
+		     char const *uri, GOIOContext *io_context)
 {
 	char   *msg = NULL;
 	GError *err = NULL;
@@ -906,7 +1028,7 @@ gboolean
 wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs, char const *uri,
 		 GOCmdContext *context)
 {
-	IOContext *io_context;
+	GOIOContext *io_context;
 	Workbook  *wb;
 	gboolean has_error, has_warning;
 
@@ -917,14 +1039,14 @@ wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs, char const *uri,
 
 	wb = wb_view_get_workbook (wbv);
 	g_object_ref (wb);
-	io_context = gnumeric_io_context_new (context);
+	io_context = go_io_context_new (context);
 
 	go_cmd_context_set_sensitive (context, FALSE);
 	wb_view_save_to_uri (wbv, fs, uri, io_context);
 	go_cmd_context_set_sensitive (context, TRUE);
 
-	has_error   = gnumeric_io_error_occurred (io_context);
-	has_warning = gnumeric_io_warning_occurred (io_context);
+	has_error   = go_io_error_occurred (io_context);
+	has_warning = go_io_warning_occurred (io_context);
 	if (!has_error) {
 		if (workbook_set_saveinfo (wb,
 			go_file_saver_get_format_level (fs), fs) &&
@@ -932,7 +1054,7 @@ wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs, char const *uri,
 			go_doc_set_dirty (GO_DOC (wb), FALSE);
 	}
 	if (has_error || has_warning)
-		gnumeric_io_error_display (io_context);
+		go_io_error_display (io_context);
 	g_object_unref (G_OBJECT (io_context));
 	g_object_unref (wb);
 
@@ -953,7 +1075,7 @@ wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs, char const *uri,
 gboolean
 wb_view_save (WorkbookView *wbv, GOCmdContext *context)
 {
-	IOContext	*io_context;
+	GOIOContext	*io_context;
 	Workbook	*wb;
 	GOFileSaver	*fs;
 	gboolean has_error, has_warning;
@@ -968,7 +1090,7 @@ wb_view_save (WorkbookView *wbv, GOCmdContext *context)
 	if (fs == NULL)
 		fs = go_file_saver_get_default ();
 
-	io_context = gnumeric_io_context_new (context);
+	io_context = go_io_context_new (context);
 	if (fs == NULL)
 		go_cmd_context_error_export (GO_CMD_CONTEXT (io_context),
 			_("Default file saver is not available."));
@@ -977,12 +1099,12 @@ wb_view_save (WorkbookView *wbv, GOCmdContext *context)
 		wb_view_save_to_uri (wbv, fs, uri, io_context);
 	}
 
-	has_error   = gnumeric_io_error_occurred (io_context);
-	has_warning = gnumeric_io_warning_occurred (io_context);
+	has_error   = go_io_error_occurred (io_context);
+	has_warning = go_io_warning_occurred (io_context);
 	if (!has_error)
 		go_doc_set_dirty (GO_DOC (wb), FALSE);
 	if (has_error || has_warning)
-		gnumeric_io_error_display (io_context);
+		go_io_error_display (io_context);
 
 	g_object_unref (G_OBJECT (io_context));
 	g_object_unref (wb);
@@ -991,10 +1113,11 @@ wb_view_save (WorkbookView *wbv, GOCmdContext *context)
 }
 
 WorkbookView *
-wb_view_new_from_input  (GsfInput *input,
-			 GOFileOpener const *optional_fmt,
-			 IOContext *io_context,
-			 char const *optional_enc)
+wb_view_new_from_input (GsfInput *input,
+			const char *optional_uri,
+			GOFileOpener const *optional_fmt,
+			GOIOContext *io_context,
+			char const *optional_enc)
 {
 	WorkbookView *new_wbv = NULL;
 
@@ -1009,19 +1132,19 @@ wb_view_new_from_input  (GsfInput *input,
 
 	/* Search for an applicable opener */
 	if (optional_fmt == NULL) {
-		FileProbeLevel pl;
+		GOFileProbeLevel pl;
 		GList *l;
 		int input_refs = G_OBJECT (input)->ref_count;
 
-		for (pl = FILE_PROBE_FILE_NAME; pl < FILE_PROBE_LAST && optional_fmt == NULL; pl++) {
+		for (pl = GO_FILE_PROBE_FILE_NAME; pl < GO_FILE_PROBE_LAST && optional_fmt == NULL; pl++) {
 			for (l = go_get_file_openers (); l != NULL; l = l->next) {
 				GOFileOpener const *tmp_fo = GO_FILE_OPENER (l->data);
 				int new_input_refs;
 				/* A name match needs to be a content match too */
 				if (go_file_opener_probe (tmp_fo, input, pl) &&
-				    (pl == FILE_PROBE_CONTENT ||
-				     !go_file_opener_can_probe	(tmp_fo, FILE_PROBE_CONTENT) ||
-				     go_file_opener_probe (tmp_fo, input, FILE_PROBE_CONTENT)))
+				    (pl == GO_FILE_PROBE_CONTENT ||
+				     !go_file_opener_can_probe	(tmp_fo, GO_FILE_PROBE_CONTENT) ||
+				     go_file_opener_probe (tmp_fo, input, GO_FILE_PROBE_CONTENT)))
 					optional_fmt = tmp_fo;
 
 				new_input_refs = G_OBJECT (input)->ref_count;
@@ -1040,24 +1163,20 @@ wb_view_new_from_input  (GsfInput *input,
 	}
 
 	if (optional_fmt != NULL) {
-		char const *input_name;
 		Workbook *new_wb;
 		gboolean old;
 
 		new_wbv = workbook_view_new (NULL);
 		new_wb = wb_view_get_workbook (new_wbv);
-		if (NULL != (input_name = gsf_input_name (input))) {
-			char *uri = go_shell_arg_to_uri (input_name);
-			go_doc_set_uri (GO_DOC (new_wb), uri);
-			g_free (uri);
-		}
+		if (optional_uri)
+			go_doc_set_uri (GO_DOC (new_wb), optional_uri);
 
 		/* disable recursive dirtying while loading */
 		old = workbook_enable_recursive_dirty (new_wb, FALSE);
 		go_file_opener_open (optional_fmt, optional_enc, io_context, new_wbv, input);
 		workbook_enable_recursive_dirty (new_wb, old);
 
-		if (gnumeric_io_error_occurred (io_context)) {
+		if (go_io_error_occurred (io_context)) {
 			g_object_unref (G_OBJECT (new_wb));
 			new_wbv = NULL;
 		} else if (workbook_sheet_count (new_wb) == 0) {
@@ -1067,6 +1186,7 @@ wb_view_new_from_input  (GsfInput *input,
 			new_wbv = NULL;
 		} else {
 			workbook_share_expressions (new_wb, TRUE);
+			workbook_optimize_style (new_wb);
 			workbook_recalc (new_wb);
 			go_doc_set_dirty (GO_DOC (new_wb), FALSE);
 		}
@@ -1092,7 +1212,7 @@ wb_view_new_from_input  (GsfInput *input,
 WorkbookView *
 wb_view_new_from_uri (char const *uri,
 		      GOFileOpener const *optional_fmt,
-		      IOContext *io_context,
+		      GOIOContext *io_context,
 		      char const *optional_enc)
 {
 	char *msg = NULL;
@@ -1108,7 +1228,7 @@ wb_view_new_from_uri (char const *uri,
 #if 0
 		g_printerr ("Reading %s\n", uri);
 #endif
-		res = wb_view_new_from_input (input,
+		res = wb_view_new_from_input (input, uri,
 					      optional_fmt, io_context,
 					      optional_enc);
 		g_object_unref (G_OBJECT (input));
